# py_desc
A simple fields descriptors tool for Python 

[![Tests](https://github.com/syth0le/py_desc/actions/workflows/run_tests.yml/badge.svg)](https://github.com/syth0le/py_desc/actions/workflows/run_tests.yml)
